/**
 * Copyright (c) 2000-2013 Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portlet.xslcontent.action;

import com.liferay.portal.kernel.portlet.DefaultConfigurationAction;
import com.liferay.portal.kernel.servlet.SessionErrors;
import com.liferay.portal.kernel.util.ArrayUtil;
import com.liferay.portal.kernel.util.StringUtil;
import com.liferay.portal.kernel.util.WebKeys;
import com.liferay.portal.theme.ThemeDisplay;

import java.net.MalformedURLException;
import java.net.URL;

import javax.portlet.ActionRequest;
import javax.portlet.ActionResponse;
import javax.portlet.PortletConfig;

/**
 * @author Brian Wing Shun Chan
 * @author Hugo Huijser
 */
public class ConfigurationActionImpl extends DefaultConfigurationAction {

	@Override
	public void processAction(
			PortletConfig portletConfig, ActionRequest actionRequest,
			ActionResponse actionResponse)
		throws Exception {

		validateUrls(actionRequest);

		super.processAction(portletConfig, actionRequest, actionResponse);
	}

	protected boolean hasAllowedProtocol(String xmlURL) {
		try {
			URL url = new URL(xmlURL);

			String protocol = url.getProtocol();

			if (ArrayUtil.contains(_PROTOCOLS, protocol)) {
				return true;
			}
		}
		catch (MalformedURLException murle) {
			return false;
		}

		return false;
	}

	protected void validateUrls(ActionRequest actionRequest) {
		ThemeDisplay themeDisplay = (ThemeDisplay)actionRequest.getAttribute(
			WebKeys.THEME_DISPLAY);

		String xmlUrl = getParameter(actionRequest, "xmlUrl");

		xmlUrl = StringUtil.replace(
			xmlUrl, "@portal_url@", themeDisplay.getPortalURL());

		if (!hasAllowedProtocol(xmlUrl)) {
			SessionErrors.add(actionRequest, "xmlUrl");
		}

		String xslUrl = getParameter(actionRequest, "xslUrl");

		xslUrl = StringUtil.replace(
			xslUrl, "@portal_url@", themeDisplay.getPortalURL());

		if (!hasAllowedProtocol(xslUrl)) {
			SessionErrors.add(actionRequest, "xslUrl");
		}
	}

	private static final String[] _PROTOCOLS = {"http", "https"};

}